<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kk">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Хабарлама режимі арнайы</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Хабарлама режимі деактивді</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Бекіту</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Активдау</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Хабарлама режимі</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Хабарлама режимінің айырмасы</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Хабарлама режимі</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Міндетімініңізді</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth айырмасы</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Отты</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Отты</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Арнайы</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth айырмасы</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 байланысқа келді</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Байланыс жасалатын...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Отты</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>%1 байланысқа келді</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Байланысқа келмеген</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Отты</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Жылдыздылық</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Жылдыз айырмасынің айырмасы</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Жылдыз айырмасынің айырмасы</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Жылдыздылық</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Жылдыз</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Пятіркі</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Сырткі</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Себті</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Жұма</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Денес</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Күні</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Клавіатура түрін қосу</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Жылдам жылдыздар</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-сын жылдыздар</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-сын жылдыздар</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Жылдыз шығармаларын қарастырыңыз</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Календарды басыңыз</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Пятіркі</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Сырткі</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Себті</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Жұма</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Денес</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Күні</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Жеке күні</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>пятіркі</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>сырткі</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>себті</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>жұма</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>денес</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>күні</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>жұлдыз</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Келесі кыйынчылар</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>DND режимі</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>DND режимінің түзімі</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Активация</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND режимі қолданылады</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND режимі деңгейленген</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>DND режимі</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Оңай жүз</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Оңай жүз қолданылады</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Оңай жүз деңгейленген</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Экрандын түзімі</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Оңай жүз</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Аралашы</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Тыныштырылған</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Жылдыз</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Күчті</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Жетілдіру</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Оңай жүзді деңгейлендіру</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Оңай жүзді қолдану</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Экрандын түзімі</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Тема: Жылдыз</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Тема: Күчті</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Тема: Автоматично</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Графический эффект</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Жылыз</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Күнгүл</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Меселелер жоқ</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Меселелердін алагы</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Меселелер</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>DND режимин жылыстыру</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>DND режимин келтіру</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Меселелер</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Түзім</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Моңголық өріспіру</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Жетілдік</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Жүрік алысу</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Моңголық өріспірімді балансы</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Power</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Power түзімі</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Көлік %1, %2 минутта кездесет</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Көлік %1, %2 сағат %3 минутта кездесет</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Көлік %1, %2 минутта жүрік алысқаны</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Көлік %1, %2 сағат %3 минутта жүрік алысқаны</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Көлік %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Көлік %1 жүрік алысу</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Көлік %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Көлік %1, жүрік алысқан</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Көлік %1, жүрік алысқа басылмаған</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Батарея</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Жүрік алысу, сапаланған жүрік алыс уақыты талап етіледі</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Калуы мүмкін уақыт талап етіледі</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 минутта кездесет</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 сағат %2 минутта кездесет</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Жүрік алысқа басылмаған</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Жүрік алысқан</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Жүрік алысу, %1 минутта кездесет</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Измактуу, %1 сағ %2 мін кайсырауы</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>%1 көлік, %2 сағ калды</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 сағ калды</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Измактуу %1, %2 сағ кайсырауы</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Измактуу, %1 сағ кайсырауы</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Пайдалануу марапаттары</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Мүзик</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Табысыз</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Түштүрүү</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Таңдашуу</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Суусу</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Қайтаратуу</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Жүктөө</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Пайдалануу марапаттары</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Тартуу</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Жарыктуу жана түштүрүү</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Жарыктуу жана тартуу</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Түштүрүү</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Кайра көрүнүү</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Күнү</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Моль</translation>
    </message>
    <message>
        <source>y</source>
        <translation>y</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>күн</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Дүйшөм</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>жұма</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>жыныс</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>чүн</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>бейсен</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>жұлдыз</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>жеке</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>январ</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>февраль</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>март</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>апрель</translation>
    </message>
    <message>
        <source>May</source>
        <translation>май</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>июнь</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>июль</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>август</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>сентябрь</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>октябрь</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>ноябрь</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>декабрь</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Календарды басыңыз</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>паза</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>жұма</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>жыныс</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>чүн</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>бейсен</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>жұлдыз</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>жума</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Гөнөк</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Шығыс</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Гөнөкteryлдік түркөлөр</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Дыбыс</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Түймөртілді жылдызтау</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Түймөртілді жылыстау</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Гөнөкteryлдік түркөлөр</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Шығыс жөнөткүч жок</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Гөнөк %1</translation>
    </message>
</context>
</TS>